pub fn parse_line_names(
input: &mut Parser<'_>,
) -> Result<OwnedSlice<CustomIdent>, ParseError>Expand description
Parse the grid line names into a vector of owned strings.
pub fn parse_line_names(
input: &mut Parser<'_>,
) -> Result<OwnedSlice<CustomIdent>, ParseError>Parse the grid line names into a vector of owned strings.